module.exports = defineTest({
	description: 'use a newline for line wraps removing a necessary semicolon (#1275)'
});
